@@ -7,16 +7,21 @@
 #                                                               |___/
 """Build packages to be submitted to Area28."""
 import argparse
-from . import __version__, package, system
+import sys
+from a28 import __version__, package, system
 
 
-def main():
+def main(args=None):
     """Main command line entry point."""
-    parser = argparse.ArgumentParser(description='Area28 development kit')
-    app = '%(prog)s ' + __version__
+    args = args or sys.argv[1:]
+    parser = argparse.ArgumentParser(
+        'a28',
+        description='Area28 development kit'
+    )
+    app = '%(prog)s version ' + __version__
     parser.add_argument('-v', '--version', action='version', version=app)
     sub = parser.add_subparsers(dest='action', required=True, help='actions')
     package.options(sub)
     system.options(sub)
-    args = parser.parse_args()
+    args = parser.parse_args(args)
     args.func(args)
